#!/usr/bin/python

import argparse
import StringIO

class Node:
	def __init__(self, inputText):
		self.inputText = inputText
		self.hostname = "None"
		self.size = 0
		self.used = 0
		self.avail = 0
		self.percentUsed = 0
		if args.debug:
			print ("Finding hostname in : " + inputText[0])
		hostnameStr = inputText[0]
		self.hostname = hostnameStr.strip().split('"')[1]

		tempStr = inputText[3].strip().split('"')[1]
		dataStr = tempStr.split()
		sizeStr = dataStr[0]
		usedStr = dataStr[1]
		availStr = dataStr[2]
		percentStr = dataStr[3]

		self.size = self.convertToSize(sizeStr)
		self.used = self.convertToSize(usedStr)
		self.avail = self.convertToSize(availStr)
		self.percentUsed = int(percentStr[:-1])

	def __str__(self):
		buf = StringIO.StringIO()
		shorterHostname = self.hostname[0:self.hostname.find(".production")]
		buf.write("%-25s:" % shorterHostname)
		buf.write("%4d GB free  " % self.avail)
		buf.write("%4d GB used  " % self.used)
		buf.write("%4d GB total  " % self.size)
		buf.write("%3d%% used" % self.percentUsed)

		return buf.getvalue()

	def convertToSize(self, sizeStr):

		if sizeStr == "0":
			return 0
		multiplier = sizeStr[-1]
		value = int(sizeStr[:-1])

		if multiplier != "G":
			if multiplier == "T":
				value = value * 1024
			elif multiplier == "P":
				value = value * 1024 * 1024
			else:
				value = 0
		return value

	def getSize(self):
		return str(self.size) + "G"

	def getUsed(self):
		return str(self.used) + "G"

	def getAvail(self):
		return str(self.avail) + "G"

	def getPercentUsed(self):
		return str(self.percentUsed) + "%"

	def getPercentAvail(self):
		return str(100 - self.percentUsed) + "%"



parser = argparse.ArgumentParser()
parser.add_argument('--debug', default = False, action='store_true', help = 'Output extra information while the script is running, to help identify errors.')
parser.add_argument('--size', default = False, action='store_true', help = 'Sort data based on the total size of node storage instead of on free space.')
parser.add_argument('--used', default = False, action='store_true', help = 'Sort data based on the used size of node storage instead of on free space.')
parser.add_argument('--desc', default = False, action='store_true', help = 'Display the storage value in descending order. By default, it is displayed in ascending order')
parser.add_argument('--lessthan', type = int, default = 100000, help = 'Display only the nodes whose sort value is less than this amount (GB)')
parser.add_argument('inputFilename', help='Name of the text file containing the ansible output')
args = parser.parse_args()


inputFilename = args.inputFilename

inputFile = open(inputFilename, "r")

inputFileLines = inputFile.readlines()
nodes = []
index = 0
while index < len(inputFileLines):
	if "start results" in inputFileLines[index]:
		nodeData = inputFileLines[index + 1: index + 5]
		if args.debug:
			print ("Node data: =====================")
			for line in nodeData:
				print line
		index = index + 4
		nodes.append(Node(nodeData))
	else:
		index = index + 1

if args.size:
	sortedNodes = sorted(nodes, key=lambda x: x.size, reverse=args.desc)
elif args.used:
	sortedNodes = sorted(nodes, key=lambda x: x.used, reverse=args.desc)
else:
	sortedNodes = sorted(nodes, key=lambda x: x.avail, reverse=args.desc)




for node in sortedNodes:
	
	if args.size:
		if node.size < args.lessthan:
			print node
	elif args.used:
		if node.used < args.lessthan:
			print node
	elif node.avail < args.lessthan:
			print node



inputFile.close()
